@@ -1,11 +1,14 @@
 """Module for plotting Numpy-like 1D histograms to the terminal."""
 
 import shutil
+from collections.abc import Sequence
 from itertools import cycle
 from typing import Optional
 
 import click
 import numpy as np
+from uhi.numpy_plottable import ensure_plottable_histogram
+from uhi.typing.plottable import PlottableHistogram
 
 DEFAULT_SYMBOLS = " |=/\\"
 COMPOSING_SYMBOLS = "/\\"
@@ -559,31 +562,23 @@ def get_plottable_protocol_bin_edges(axis):
 def get_count_edges(hist):
     """Get bin contents and edges from a compatible histogram."""
 
-    # Try the PlottableProtocol
-    try:
+    # Support sequence of histograms
+    if isinstance(hist, Sequence) and isinstance(hist[0], PlottableHistogram):
+        count = np.stack([h.values() for h in hist])
+        edges = get_plottable_protocol_bin_edges(hist[0].axes[0])
+        for other_edges in (
+            get_plottable_protocol_bin_edges(h.axes[0]) for h in hist[1:]
+        ):
+            np.testing.assert_allclose(edges, other_edges)
+
+    else:
+        # Single histogram or (a,b,c, edges) tuple:
+        # Make sure we have a PlottableProtocol histogram
+        hist = ensure_plottable_histogram(hist)
+
+        # Use the PlottableProtocol
         count = hist.values()
         edges = get_plottable_protocol_bin_edges(hist.axes[0])
-        # Each bin comes with both upper and lower edge
-        # Merge
-        hist = count, edges
-    except Exception:
-        pass
-
-    # Try generic numpy conversion methods
-    try:
-        hist = hist.to_numpy()
-    except Exception:
-        pass
-    try:
-        hist = hist.numpy()
-    except Exception:
-        pass
-
-    # Try the Numpy interface
-    try:
-        count, edges = hist
-    except ValueError:
-        raise ValueError("Not a compatible histogram!")
 
     return count, edges
 
@@ -606,7 +601,7 @@ def print_hist(hist, file=click.get_text_stream("stdout"), **kwargs):  # noqa: B
     click.echo(hist_formatter.format_histogram(count), nl=False, file=file)
 
 
-def text_hist(*args, **kwargs):
+def text_hist(*args, density=None, **kwargs):
     """Thin wrapper around ``numpy.histogram``."""
 
     print_kwargs = {
@@ -618,9 +613,9 @@ def text_hist(*args, **kwargs):
         "bg_colors": kwargs.pop("bg_colors", DEFAULT_BG_COLORS),
         "count_area": kwargs.pop("count_area", True),
     }
-    density = kwargs.pop("density", False)
     if density:
         print_kwargs["count_area"] = False
-    hist = np.histogram(*args, density=density, **kwargs)
+    kwargs["density"] = density
+    hist = np.histogram(*args, **kwargs)
     print_hist(hist, **print_kwargs)
     return hist
